==============================
Examples for Physics/Mechanics
==============================

Here are some examples that illustrate how one typically uses this module. We
have ordered the examples roughly according to increasing difficulty. If you
have used this module to do something others might find useful or interesting,
consider adding it here!


.. toctree::
    :maxdepth: 1

    examples/rollingdisc_example.rst
    examples/bicycle_example.rst
    examples/lin_pend_nonmin_example.rst
